.. _nomenclature:
Nomenclature
============

Variables, Functions, and other Symbols
---------------------------------------

.. math::
    \begin{aligned}
        A &- \text{Sensitivity matrix} \\
        \mathbf{f} &- \text{ode field} \\
        H &- \text{Hamiltonian function} \\
        Id_M &- \text{Identity on M} \\
        t &- \text{Time, or other independent variable} \\
        \mathbf{q} &- \text{Quads} \\
        \mathbf{y} &- \text{States} \\
        \mu_i &- \text{Lagrange multiplier} \\
        \Delta &- \text{State-transition matrix} \\
    \end{aligned}

Operators
---------

.. math::
    \begin{aligned}
        \rightarrow &- \text{Mapping} \\
        \circ &- \text{Composition}
    \end{aligned}
